#!/usr/bin/perl
use strict;
use Getopt::Std;

#----------------------- GET PARMS  -----------------------------
my $usage="
run-twain.pl <reference.fasta> <query.fasta> <mummer-dir> <ref.iso> 
             <query.iso> <ref-out.gff> <query-out.gff> <oasis-dir>
             <rose-dir> [options]

required parameters:
    <*.fasta> are the genome fasta files
    <mummer-dir> is the directory containing the MUMmer executables
    <oasis-dir> is the directory containing the OASIS executables
    <rose-dir> is the directory containing the ROSE executables
    <*.iso> are the TigrScan isochore files (see TigrScan documentation)
    <*-out.gff> will contain the gene prediction outputs upon completion

options:
    -r <*.gff> = ab initio \"seed\" predictions for ROSE (reference)
    -q <*.gff> = ab initio \"seed\" predictions for ROSE (query)
";

getopts('q:r:') || die $usage;
my $qgenes=$Getopt::Std::opt_q;
my $rgenes=$Getopt::Std::opt_r;

die "$usage\n" unless @ARGV==9;
my ($refSeq,$querySeq,$promerDir,$refIso,$queryIso,$refOut,$queryOut,
    $oasisDir,$roseDir)=@ARGV;

#----------------------- RUN ROSE -----------------------------
my $command="runrose.pl $refSeq $querySeq -p $promerDir -o roseout.tmp -d $roseDir";
if(defined $rgenes && !defined $qgenes ||
   defined $qgenes && !defined $rgenes)
  {die "-r and -q must be given together\n"}
if(defined $rgenes) {$command.=" -r $rgenes -q $qgenes"}
system($command);

#----------------------- RUN OASIS ----------------------------
$command="runoasis.pl roseout.tmp $refSeq $querySeq $refIso $queryIso $refOut $queryOut -p $promerDir -d $oasisDir";
system($command);

#----------------------- CLEAN UP -----------------------------
system("rm *.tmp");
print "done.\n";

