#!/usr/bin/perl

use strict;
use Getopt::Std;

my $usage = q/
  Run Rose module.
  Usage:
    runrose.pl <reference genome fasta file> <query genome fasta file> [optional_parameters]
    
    [optional_parameters]

    -r [*.gff] gene predictions on reference file
    -q [*.gff] gene predictions on query file
    -d dir     rose directory for runing rose (default: is rose\/)
    -p dir     promer\/nucmer directory
    -o file    output file for rose
    
/;

die $usage if (@ARGV<2);

# get options
{
    my @args;
    while ($ARGV[0] && $ARGV[0]!~/^\-/) {
         push(@args, shift(@ARGV)); }
    getopts('q:r:d:p:o:') || die $usage;
    push(@ARGV, @args); 
}

my ($reffile,$quefile)=@ARGV;

my $rosedir=$Getopt::Std::opt_d||"rose/";
my $promerdir=$Getopt::Std::opt_p;
my $qgenes=$Getopt::Std::opt_q;
my $rgenes=$Getopt::Std::opt_r;


my ($refname,$quename);

{
    my @temp=split(/\//,$reffile);
    $refname=$temp[$#temp];
    $refname =~ s/(.+)\.fasta$/$1/ ;
    @temp=split(/\//,$quefile);
    $quename=$temp[$#temp];
    $quename =~ s/(.+)\.fasta$/$1/ ;
}



# run promer
my $command="";
if($promerdir) {
    $command=$promerdir."/";
}
my $deltafile=$refname."_".$quename;

my $outputfile=$Getopt::Std::opt_o||"$deltafile.regions";

$command.="promer -p $deltafile $reffile $quefile";
my $status=system($command);
die print STDERR "ERROR: promer exited funny: $?" unless $status ==0;

$command="";
if($promerdir) {
    $command=$promerdir."/";
}
$command.="show-coords -c -l -r $deltafile.delta > $deltafile.coords";
$status=system($command);
die print STDERR "ERROR: show-coords exited funny: $?" unless $status ==0;

$command="$rosedir/OrthoDetect.pl $deltafile.coords -c";
if($rgenes) { 
    $command.=" -r $rgenes";
}
if($qgenes) {
    $command.=" -q $qgenes";
}
$command.=" -o $outputfile";
$status=system($command);
die print STDERR "ERROR: OrthoDetect.pl exited funny: $?" unless $status ==0;
